# Exhaustive Search with Bayesian Model Averaging (ExhBMA)

# Installation
```
pip install exhbma
```

# How to use
Please see notebooks in `tutorials/`.

# API document
In preparing.

# Research paper
In preparing.
